<?php
/*
 * HelperSip: A class that provides some functions to generate the GUI for the SIP configuration.
 *
 * Copyright (C) 2017 beroNet GmbH
 *
 * Author: Miguel Palmer <mp@beronet.com>
 */
require_once "/usr/local/www/berogui/includes/isgwtelnet.php";
require_once "/usr/local/www/berogui/includes/profileParser.php";

class HelperSip {

	public static $fields = array("name", "sip_proxy", "sip_registrar", "sip_domain", "user", "auth_user", "displayname", "secret",
		"sip_transport", "stunserver", "externip", "register", "validation", "regrefresh", "register_option", "sip_custom_port",
		"config", "matchtype", "enum_support", "enum_search_domains", "keepalive_interval", "call_transfer_method", "sip_stack",
		"t38", "ie_on_sip", "wait_for_cancel", "dtmfmode", "s2i_cpt",
		"i2s_cpt", "failover_proxy", "failover_timeout", "sip_national_code", "sip_international_code",
		"isdn2sip_destination_numformat", "isdn2sip_source_numformat", "dialplan_international_prefix", "sip2dialplan_dad_prefix_setting",
		"sip2dialplan_oad_prefix_setting", "srtp_mode",
		"from_sip_src_setting", "from_sip_dest_setting", "sip_to_user_setting", "sip_from_user_setting", "sip_from_display_setting",
		"codecs", "s2s_nat_opener", "use_privacy_header", "sip_pai_user_setting", "sip_ppi_user_setting", "sip_contact_user_setting", "qvalue", "dnssrv", "addit_options");
		
	public static $config_values = array("t38", "dtmfmode", "codecs", "ie_on_sip", "from_sip_src_setting", "from_sip_dest_setting",
		"wait_for_cancel", "sip_to_user_setting", "sip_from_user_setting",
		"sip_from_display_setting", "failover_proxy", "failover_timeout", "s2i_cpt", "i2s_cpt",
		"sip_national_code", "sip_international_code", "isdn2sip_destination_numformat", "isdn2sip_source_numformat",
		"dialplan_international_prefix", "sip2dialplan_dad_prefix_setting",
		"sip2dialplan_oad_prefix_setting", "srtp_mode", "s2s_nat_opener", "use_privacy_header", "sip_pai_user_setting", "sip_ppi_user_setting", "sip_contact_user_setting", "qvalue", "dnssrv", "srtp_crypto_suites");
		
	public static $configSave = array('t38', 'ie_on_sip', 'wait_for_cancel', 'dtmfmode', 's2i_cpt',
		'i2s_cpt', 'failover_proxy', 'failover_timeout', 'sip_national_code', 'sip_international_code',
		'isdn2sip_destination_numformat', "isdn2sip_source_numformat", 'dialplan_international_prefix', 'sip2dialplan_dad_prefix_setting',
		'sip2dialplan_oad_prefix_setting', 'srtp_mode', "s2s_nat_opener", "use_privacy_header", "qvalue", "dnssrv");

	public static function getValue(&$ba, $id, $option, $fixedSettings) {
		if ($id === null)
			return $fixedSettings[$option];

		$query = $ba->select("select $option from sip where id=\"" . sqlite_escape_string($id) . "\"");
		return stripslashes(sqlite_fetch_single($query));
	}

	//Return text field
	public static function textField(&$ba, $id, $col, $fixedSettings, $default = "") {
		$option = ($col === "enum_search_domains") ? trim($col, "s") : $col;
		$value = self::getValue($ba, $id, $option, $fixedSettings);
		if ($default !== "" && $value == "") {
			$value = $default;
		}
		$ret = "<input class='form-control input-sm' name='" . $col . "' id='" . $col . "' value='" . $value . "'>";
		return $ret;
	}

	//Return password field
	public static function passwordField(&$ba, $id, $col, $fixedSettings) {
		$value = self::getValue($ba, $id, $col, $fixedSettings);
		$ret = "<input class='form-control input-sm' name='" . $col . "' id='" . $col . "' type='password' autocomplete='new-password' value='" . $value . "'>";
		return $ret;
	}

	//Return a dropdown field
	public static function dropdown(&$ba, $id, $col, $fixedSettings, $options, $default = "") {
		$value = self::getValue($ba, $id, $col, $fixedSettings);
		$sel .= "<select class='form-control input-sm' name='" . $col . "'>";
		if ($value !== "") {
			$default = $value;
		}
		foreach ($options as $name => $value) {
			$sel .= ($name == $default) ? "<option value='" . $name . "' selected>" . $value . "</option>" : "<option value='" . $name . "'>" . $value . "</option>";
		}
		$sel .= "</select>";
		return $sel;
	}



	//Return a checkbox
	public static function checkbox(&$ba, $id, $col, $fixedSettings, $htmlOptions = "", $default = "") {
	
		$value = self::getValue($ba, $id, $col, $fixedSettings);
		
		if (intval($value) === 1) {
			$default = "checked";
		}
		elseif (intval($value) === 0) {
			$default = "";
		}
		$ret = "<input type='hidden' name='$col' value='0'>"
			. "<input type='checkbox' name='$col' id='$col'  value='1' $default $htmlOptions>";
		return $ret;
	}

	/**
	 * Additional config string bei einem Update
	 */
	public static function showdefmc($fixedSettings) {
		require_once '/usr/local/www/berogui/includes/Helper/Helper.php';
		$zeilen = Helper::getConfigFromIsgw();
		foreach ($zeilen as $zeile) {
			if (stripos($zeile, '[') === 0) {
				preg_match("/\[(?<bez>.+)\]\[(?<name>.+)\][\s]*(?<desc>.+)[\s]*\<(?<val>.*)\>[\s]*'(?<def>.*)'/", $zeile, $res);
				if (!in_array($res['name'], self::$config_values) && ($res['bez'] == "s" || $res['bez'] == "*")) {
					?>
					<script>
						var extra_tooltip = document.getElementById('extra_tooltip');
						extra_tooltip.innerHTML = extra_tooltip.innerHTML + '<p><? echo DIALPLAN_OPTION_DIS; ?><b>&nbsp;' +
								'<? echo $res['name']; ?></b><br><? echo DIALPLAN_VALUES_DIS; ?><b>&nbsp;&lt;' +
								'<? echo $res['val']; ?>&gt;</b><br>Default:<b>&nbsp;<? echo $res['def']; ?></b><br><i>' +
								'<? echo htmlspecialchars($res['desc'], ENT_QUOTES); ?></i></p><br>';
					</script>
					<?php
				}
			}
		}
		if (!isset($_GET['id'])) {
			$config = $fixedSettings['config'];
		} else {
			$ba = new beroAri();
			$query = $ba->select("select config from sip where id='" . sqlite_escape_string($_GET['id']) . "'");
			while ($entry = $ba->fetch_array($query)) {
				$config = $entry['config'];
			}
		}
		if ($config != "") {
			$configs = explode(',', $config);
			foreach ($configs as $value) {
				$key = explode('=', $value, 2);
				if ($key[0] != "" && $key[1] != "" && !in_array($key[0], self::$config_values)) {
					?>
					<script>
						$('#addit_options').append('<? echo $key[0]; ?>=<? echo $key[1]; ?>\n');
					</script>
					<?php
				} elseif ($key[0] != "" && $key[1] == "" && !in_array($key[0], self::$config_values)) {
					?>
					<script>
						$('#addit_options').append('<? echo $key[0]; ?>=\n');
					</script>
					<?php
				}
			}
		}
	}

	/**
	 * Additional config string beim Hinzufügen einer Portgruppe
	 */
	public static function showConfAdd() {
		require_once '/usr/local/www/berogui/includes/Helper/Helper.php';
		$zeilen = Helper::getConfigFromIsgw();
		foreach ($zeilen as $zeile) {
			if (stripos($zeile, '[') === 0) {
				preg_match("/\[(?<bez>.+)\]\[(?<name>.+)\][\s]*(?<desc>.+)[\s]*\<(?<val>.*)\>[\s]*'(?<def>.*)'/", $zeile, $res);
				if (!in_array($res['name'], self::$config_values) && ($res['bez'] == "s" || $res['bez'] == "*")) {
					?>
					<script>
						$('#extra_tooltip').html($('#extra_tooltip').prop("innerHTML") +
								'<p><? echo DIALPLAN_OPTION_DIS; ?><b>&nbsp;<? echo $res['name']; ?></b><br><? echo DIALPLAN_VALUES_DIS; ?>' +
								'<b>&nbsp;&lt;<? echo $res['val']; ?>&gt;</b><br>Default:<b>&nbsp;<? echo $res['def']; ?></b><br><i>' +
								'<? echo htmlspecialchars($res['desc'], ENT_QUOTES); ?></i></p><br>');
					</script>
					<?php
				}
			}
		}
	}

	public static function profiles($manual = TRUE) {
		$categories = array();
		$type = "<script type='text/javascript'>"
			. "function getProfile() {
            selectedOpt = $('#type').val();
            $('#type option').each(function ()
            {
                if (selectedOpt == 'manual')
                    $('[id=\"' + $(this).val() + '\"]').hide();
                else if (selectedOpt == $(this).val())
                    $('[id=\"' + $(this).val() + '\"]').show();
                else
                    $('[id=\"' + $(this).val() + '\"]').hide();
            });
        }"
			. "</script>";
		$type .= "<select name='type' id='type' class='form-control input-sm' onChange='getProfile();'>";
		$type .= ($manual === TRUE) ? "<option value='manual'>Manual</option>" : "<option value='manual'>- Category -</option>";
		$dh = @opendir("/usr/conf/profile");
		if (false !== $dh) {
			while ($file = readdir($dh)) {
				if ("." == $file || ".." == $file)
					continue;
				array_push($categories, $file);
				$type .= '<option value=\'' . $file . '\'>' . $file . '</option>';
			}
		}
		$type .= "</select>";
		if (false !== $dh) {
			foreach ($categories as $category) {
				$profile .= "<select name='$category' id='$category' class='form-control input-sm profile' style='display:none;'>";
				if (!$manual) {
					$profile .= "<option value='manual'>- Profile -</option>";
				}
				$dh = @opendir("/usr/conf/profile/" . $category);
				if (false === $dh) {
					return false;
				}
				while ($file = readdir($dh)) {
					if ("." == $file || ".." == $file)
						continue;
					$profile .= '<option value=\'' . $file . '\'>' . $file . '</option>';
				}
				$profile .= "</select>";
			}
		}
		return $type . $profile;
	}

	public static function matchtype(&$ba, $id, $fixedSettings) {
		$option = self::getValue($ba, $id, "matchtype", $fixedSettings);
		$manual = self::getValue($ba, $id, "matchtype_manual", $fixedSettings);
		$option = explode("|", $option);
		(in_array("address", $option) || $option[0] == "") ? $checked = "checked" : $checked = "";
		$checkbox .= "<div class='checkbox pull-left'>"
			. "<label><input type='checkbox' name='matchtype[]' id='address' value='address' $checked>IP Address</label>"
			. "</div>";

		(in_array("fromuser", $option)) ? $checked = "checked" : $checked = "";
		$checkbox .= "<div class='clearfix'></div>"
			. "<div class='checkbox pull-left'>"
			. "<label><input type='checkbox' name='matchtype[]' value='fromuser' $checked>From User</label>"
			. "</div>";

		(in_array("touser", $option)) ? $checked = "checked" : $checked = "";
		$checkbox .= "<div class='clearfix'></div>"
			. "<div class='checkbox pull-left'>"
			. "<label><input type='checkbox' name='matchtype[]' value='touser' $checked>To User</label>"
			. "</div>";

		(in_array("contactuser", $option)) ? $checked = "checked" : $checked = "";
		$checkbox .= "<div class='clearfix'></div>"
			. "<div class='checkbox pull-left'><label><input type='checkbox' name='matchtype[]' value='contactuser' $checked>Contact User</label>"
			. "</div>";

		(in_array("requesturluser", $option)) ? $checked = "checked" : $checked = "";
		$checkbox .= "<div class='clearfix'></div>"
			. "<div class='checkbox pull-left'>"
			. "<label><input type='checkbox' name='matchtype[]' value='requesturluser' $checked>Request-URI User</label>"
			. "</div>";

		(in_array("manual", $option)) ? $checked = "checked" : $checked = "";
		$checkbox .= "<div class='clearfix'></div>"
			. "<div class='checkbox pull-left'>"
			. "<label><input type='checkbox' name='matchtype[]' id='manual' value='manual' $checked>Manual</label>"
			. "</div>";
		$checkbox .= "<div class='clearfix'></div>"
			. "<div class='checkbox pull-left'>"
			. "<label><input name='matchtype_manual' class='form-control input-sm' value='" . $manual . "' size='14' /></label>"
			. "</div>";
		return $checkbox;
	}
	
	public static function udpports(&$ba) {
		return $ba->get("udpports");
	}

}
